@@ -43,6 +43,8 @@ class SqlQueue(object):
                 sql = sql[:-1]
             mode = ""
             if len(data) != 0:
+                if isinstance(data[0], list):
+                    data = tuple([tuple(_) for _ in data])
                 if isinstance(data[0], tuple):
                     mode = "many"
                 else:
@@ -136,12 +138,15 @@ class SqlQueueE(SqlQueue):
         super().__init__(server, db, timeout_commit, depth)
         host = "127.199.71.10"
         port = 39292
-        if not self.is_server:
+        if self.is_server:
+            if key_pair is None:
+                key_pair = EasyRSA(bits=1024).gen_key_pair()
+            self.ess = ESS(key_pair, self.functions, host, port)
+            thread = threading.Thread(target=self.ess.start)
+            thread.daemon = True
+            thread.start()
+        else:
             self.sc = ESC(host, port)
-        if key_pair is None:
-            key_pair = EasyRSA(bits=1024).gen_key_pair()
-        self.ess = ESS(key_pair, self.functions, host, port)
-        threading.Thread(target=self.ess.start).start()
 
     def stop(self):
         super().stop()
@@ -156,10 +161,13 @@ class SqlQueueU(SqlQueue):
         super().__init__(server, db, timeout_commit, depth)
         host = "127.199.71.10"
         port = 39292
-        if not self.is_server:
+        if self.is_server:
+            self.uss = USS(self.functions, host, port)
+            thread = threading.Thread(target=self.uss.start)
+            thread.daemon = True
+            thread.start()
+        else:
             self.sc = USC(host, port)
-        self.uss = USS(self.functions, host, port)
-        threading.Thread(target=self.uss.start).start()
 
     def stop(self):
         super().stop()
